@@ -6,6 +6,7 @@ use File::Spec::Functions qw( catdir updir );
 use FindBin               qw( $Bin );
 use lib               catdir( $Bin, updir, 'lib' ), catdir( $Bin, 'lib' );
 
+use Test::More;
 use Test::Requires { version => 0.88 };
 use Module::Build;
 
@@ -15,6 +16,7 @@ BEGIN {
    my $builder = eval { Module::Build->current };
       $builder and $notes = $builder->notes;
       $perl_ver = $notes->{min_perl_version} || 5.008;
+      $Bin =~ m{ : .+ : }mx and plan skip_all => 'Two colons in $Bin path';
 }
 
 use Test::Requires "${perl_ver}";
